==> de.flapdoodle.embed.process-2.0.2-sources.jar: de/flapdoodle/embed/process/io/Slf4jStreamProcessor.java <==
/**
 * Copyright (C) 2011
 *   Michael Mosmann <michael@mosmann.de>
 *   Martin Jöhren <m.joehren@googlemail.com>
 *
 * with contributions from
 * 	konstantin-ba@github,
	Archimedes Trajano (trajano@github),
	Kevin D. Keck (kdkeck@github),
	Ben McCann (benmccann@github)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.embed.process.io;

import org.slf4j.Logger;

public class Slf4jStreamProcessor implements IStreamProcessor {

    private final Logger logger;
    private final Slf4jLevel level;


    public Slf4jStreamProcessor(Logger logger, Slf4jLevel level) {
        this.logger = logger;
        this.level = level;
    }

    public void process(String line) {
        level.log(logger, stripLineEndings(line));
    }

    public void onProcessed() {
    }


    protected String stripLineEndings(String line) {
        // we still need to remove line endings that are passed on by StreamToLineProcessor...
        return line.replaceAll("[\n\r]+", "");
    }
}

==> de.flapdoodle.embed.process-3.1.7-sources.jar: de/flapdoodle/embed/process/io/Slf4jStreamProcessor.java <==
/**
 * Copyright (C) 2011
 *   Michael Mosmann <michael@mosmann.de>
 *   Martin Jöhren <m.joehren@googlemail.com>
 *
 * with contributions from
 * 	konstantin-ba@github,
	Archimedes Trajano (trajano@github),
	Kevin D. Keck (kdkeck@github),
	Ben McCann (benmccann@github)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.embed.process.io;

import org.slf4j.Logger;

public class Slf4jStreamProcessor implements StreamProcessor {

    private final Logger logger;
    private final Slf4jLevel level;


    public Slf4jStreamProcessor(Logger logger, Slf4jLevel level) {
        this.logger = logger;
        this.level = level;
    }

    public void process(String line) {
        level.log(logger, stripLineEndings(line));
    }

    public void onProcessed() {
    }


    protected String stripLineEndings(String line) {
        // we still need to remove line endings that are passed on by StreamToLineProcessor...
        return line.replaceAll("[\n\r]+", "");
    }
}
